@@ -1,4 +1,4 @@
-insert into member (id,loginid, name, passwd,mailsendedfolder) values (0, 'root', 'root', 'root', 'Sent');
+insert into member (id,loginid, name, passwd) values (0, 'root', 'root', 'root');
 insert into rolemember (roleid, memberid) values (0, 0);
 insert into daosequence values('rhtym role id', 1);
 insert into daosequence values('rhtym member id', 1);
@@ -14,4 +14,4 @@ insert into daosequence values('rhtym RhythmTree id', 1);
 insert into daosequence values('rhtym AssignPermission id', 1);
 insert into daosequence values('rhythm com.kickmogu.rhythm.core.MailSetting id', 1);
 insert into daosequence values('rhtym todo id', 1);
-insert into daosequence values('rhtym timecard id', 1);
\ No newline at end of file
+insert into daosequence values('rhtym timecard id', 1);
